about summary refs log tree commit diff
path: root/pkgs/development/libraries/libdatachannel
diff options
context:
space:
mode:
authorFranz Pletz <fpletz@fnordicwalking.de>2023-10-31 15:47:20 +0000
committerFranz Pletz <fpletz@fnordicwalking.de>2023-10-31 15:48:40 +0000
commitfb83fbd42eaa6c7400aa08e377d494f23c4cb717 (patch)
tree75a49e16466ad636d0beb59293327ed629f6d151 /pkgs/development/libraries/libdatachannel
parent6e3351493def812e45c4d167e6cccf1cb81a2bd9 (diff)
libdatachannel: fix include path in cmake files
Previously it referred to $out/include which doesn't exist.
Diffstat (limited to 'pkgs/development/libraries/libdatachannel')
-rw-r--r--pkgs/development/libraries/libdatachannel/default.nix6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkgs/development/libraries/libdatachannel/default.nix b/pkgs/development/libraries/libdatachannel/default.nix
index 4561f04ba06b5..8f681e18cba67 100644
--- a/pkgs/development/libraries/libdatachannel/default.nix
+++ b/pkgs/development/libraries/libdatachannel/default.nix
@@ -46,9 +46,9 @@ stdenv.mkDerivation rec {
   ];
 
   postFixup = ''
-    # Fix shared library path that will be incorrect on move to "dev" output
-    substituteInPlace "$dev/lib/cmake/LibDataChannel/LibDataChannelTargets-release.cmake" \
-      --replace "\''${_IMPORT_PREFIX}/lib" "$out/lib"
+    # Fix include path that will be incorrect due to the "dev" output
+    substituteInPlace "$dev/lib/cmake/LibDataChannel/LibDataChannelTargets.cmake" \
+      --replace "\''${_IMPORT_PREFIX}/include" "$dev/include"
   '';
 
   meta = with lib; {